@@ -1,4 +1,4 @@
-/* $Id: directory-handle.h,v 1.7 2004/02/13 18:22:29 murrayc Exp $ */
+/* $Id: directory-handle.h,v 1.8 2005/04/15 10:56:16 murrayc Exp $ */
 
 /* Copyright 2003 gnome-vfsmm Development Team
  *
@@ -73,6 +73,9 @@ public:
 
   Glib::RefPtr<FileInfo> read_next(bool& file_exists) throw(exception);
 
+  /** @result If the file does not exist then this will be false.
+   */
+  Glib::RefPtr<FileInfo> read_next() throw(exception);
   
   GnomeVFSDirectoryHandle* gobj();
   const GnomeVFSDirectoryHandle* gobj() const;  
